==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/service.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  name: 'Service Name',
  required_restart: 'Restart',
  select_service: 'Services',
  assign_component: 'Assign Component',
  configure_service: 'Configure Service',
  service_overview: 'Service Overview',
  install_component: 'Install',
  service_list: 'Service List',
  pending_installation_services: 'Selected Services',
  select_host: 'Select  Host',
  host_preview: 'Host Preview',
  please_enter_search_keyword: 'Please enter search keyword',
  component_host_assignment: 'Assign at least one host for each component',
  service_selection: 'Please select services to install',
  dependencies_conflict_msg: '{0} requires infra service {1} to be installed first',
  dependencies_msg: '{0} requires service {1}, add it also?',
  capture_snapshot: 'Capture Snapshot',
  snapshot_management: 'Snapshot Management',
  snapshot_name: 'Name',
  snapshot_description: 'Description',
  snapshot_notes: 'Snapshot Notes'
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/en_US/service.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  name: 'Service Name',
  required_restart: 'Restart',
  select_service: 'Services',
  assign_component: 'Assign Component',
  configure_service: 'Configure Service',
  service_overview: 'Service Overview',
  install_component: 'Install',
  service_list: 'Service List',
  pending_installation_services: 'Selected Services',
  select_host: 'Select  Host',
  host_preview: 'Host Preview',
  please_enter_search_keyword: 'Please enter search keyword',
  component_host_assignment: 'Assign at least one host for each component',
  service_selection: 'Please select services to install',
  dependencies_conflict_msg: '{0} requires infra service {1} to be installed first',
  dependencies_add_msg: '{0} requires service {1}, add it also?',
  dependencies_remove_msg: '{0} requires service {1}, remove it also?',
  capture_snapshot: 'Capture Snapshot',
  snapshot_management: 'Snapshot Management',
  snapshot_name: 'Name',
  snapshot_description: 'Description',
  snapshot_notes: 'Snapshot Notes',
  exact: '{0} requires exactly {1} host(s).',
  range: '{0} requires between {1} and {2} host(s).',
  minOnly: '{0} requires at least {1} host(s).',
  required: 'Field cannot be empty.'
}
